@@ -11,20 +11,19 @@ class Diabetes(Dataset):
     as well as the response of interest,
     a quantitative measure of disease progression one year after baseline.
     Number of Instances: 442
-    Number of Attributes:
-    First 10 columns are numeric predictive values.
+    Number of Attributes:First 10 columns are numeric predictive values.
     Target: Column 11 is a quantitative measure of disease progression one year after baseline.
     Attribute Information:
-    * age age in years
-    * sex
-    * bmi body mass index
-    * bp average blood pressure
-    * s1 tc, total serum cholesterol
-    * s2 ldl, low-density lipoproteins
-    * s3 hdl, high-density lipoproteins
-    * s4 tch, total cholesterol / HDL
-    * s5 ltg, possibly log of serum triglycerides level
-    * s6 glu, blood sugar level
+        * age age in years
+        * sex
+        * bmi body mass index
+        * bp average blood pressure
+        * s1 tc, total serum cholesterol
+        * s2 ldl, low-density lipoproteins
+        * s3 hdl, high-density lipoproteins
+        * s4 tch, total cholesterol / HDL
+        * s5 ltg, possibly log of serum triglycerides level
+        * s6 glu, blood sugar level
 
     Args:
         feature_type (torch.dtype): The data type of the features. Defaults to torch.float.
